@@ -10,7 +10,7 @@
  * Once you qualify for requirements, you're ready to use it. Just run it and
  * you'll be present with current ScrollZ setup (read from include/defs.h).
  * Follow on-screen instructions and make your choices. Either use 'Q' to quit
- * or press 'S' to save. If you opted for latter, just type make irc and in a
+ * or press 'W' to save. If you opted for latter, just type make irc and in a
  * matter of minutes you will have binary of your choice.
  *
  * Now that ScrollZ has a lot of compile-time options, we needed this so one
@@ -20,9 +20,9 @@
  * Note that this should reduce compile time too since it only recompiles
  * files that are affected by selected options. If you need more info or you
  * have comments on this code, send e-mail to:
- * flier@scrollz.com
+ * flier@scrollz.org
  * 
- * $Id: SZdist.c,v 1.41 2003/05/04 18:06:06 f Exp $
+ * $Id: SZdist.c,v 1.43 2006/11/01 11:46:16 f Exp $
  */
 
 #include <stdio.h>
@@ -255,7 +255,7 @@ char **argv;
     strcpy(tmpbuf,"rm source/irc.o source/ctcp.o");
     do {
         printf("[2J[1;1H");
-        printf("Enter [1mletter[0m to toggle option on/off, '[1mQ[0m' to quit, '[1mS[0m' to save and quit\n");
+        printf("Enter [1mletter[0m to toggle option on/off, '[1mQ[0m' to quit, '[1mW[0m' to save and quit\n");
         printf("-------------------------------------------------------------------------------\n");
         printf(" [1mA[0m - WANTANSI      %s - color capable client\n",
                onoffstr(choice&WANTANSI,onoffbuf));
