@@ -33,7 +33,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: config.h,v 1.20 2004/08/13 18:38:56 f Exp $
+ * $Id: config.h,v 1.23 2006/10/31 12:31:27 f Exp $
  */
 
 #ifndef __config_h_
@@ -132,6 +132,7 @@
 #define DEFAULT_CTCP_REPLY_IGNORE_SECONDS 10
 #define DEFAULT_DCC_BLOCK_SIZE 2048
 #define DEFAULT_DISPLAY 1
+#define DEFAULT_DISPLAY_ENCODING "UTF-8"
 #define DEFAULT_DISPLAY_ANSI 1
 #define DEFAULT_EIGHT_BIT_CHARACTERS 1
 #define DEFAULT_ENCRYPT_PROGRAM NULL
@@ -155,8 +156,10 @@
 #define DEFAULT_HYPER_DCC 0
 #define DEFAULT_INDENT 1
 #define DEFAULT_INPUT_ALIASES 0
+#define DEFAULT_INPUT_ENCODING "UTF-8"
 #define DEFAULT_INPUT_PROMPT NULL
 #define DEFAULT_INPUT_PROTECTION 1
+#define DEFAULT_IRC_ENCODING "UTF-8"
 #define DEFAULT_INSERT_MODE 1
 #define DEFAULT_INVERSE_VIDEO 1
 #define DEFAULT_ISO2022_SUPPORT 0
@@ -202,18 +205,21 @@
 #define DEFAULT_STATUS_CLOCK "time is %T"
 #define DEFAULT_STATUS_FORMAT "[%R] %* %B%H%A%S %W %F %>"
 #define DEFAULT_STATUS_FORMAT1 "[%R] %*%@%N%#%B%H%C%+%A%Q%S%I%O %W %F %> [lj %3]"
-#define DEFAULT_STATUS_FORMAT2 "%1 [lag %2] %M [g %6] [s %5] [%D:%E:%P:%L:%7:%8] %> %T"
+#define DEFAULT_STATUS_FORMAT2 "%1 [lag %2] %M [g %6] [s %5]%P%s [%D:%E:%X:%L:%7:%8] %> %T"
 #define DEFAULT_STATUS_FORMAT3 "%U [topic %9] %>"
 #define	DEFAULT_STATUS_GROUP " [%G]"
 #define DEFAULT_STATUS_HOLD " [..more..]"
 #define DEFAULT_STATUS_HOLD_LINES " (%B)"
 #define DEFAULT_STATUS_INSERT ""
+#define DEFAULT_STATUS_LINES 2
 #define DEFAULT_STATUS_MAIL "[m %M]"
 #define DEFAULT_STATUS_MODE " (+%+)"
 #define DEFAULT_STATUS_NOTIFY " [a:%F]"
 #define DEFAULT_STATUS_OPER "*"
 #define DEFAULT_STATUS_OVERWRITE " (ow)"
 #define DEFAULT_STATUS_QUERY " [Q/%Q]"
+#define DEFAULT_STATUS_SCROLLED " -scr-"
+#define DEFAULT_STATUS_SCROLLED_LINES " (%s)"
 #define DEFAULT_STATUS_SERVER " via %S"
 #define DEFAULT_STATUS_UMODE " (+%#)"
 #define DEFAULT_STATUS_UPTIME "[up %dd %hh %mm]"
@@ -228,7 +234,6 @@
 #define DEFAULT_UNDERLINE_VIDEO 1
 #define DEFAULT_USERINFO ""
 #define DEFAULT_USER_WALLOPS 0
-#define DEFAULT_USE_OLD_MSG 0
 #define DEFAULT_VERBOSE_CTCP 1
 #define DEFAULT_WARN_OF_IGNORES 1
 #define DEFAULT_XTERM_GEOMOPTSTR "-geom"
@@ -261,6 +266,7 @@
 #undef DEFAULT_STATUS_MAIL
 #undef DEFAULT_STATUS_MODE
 #undef DEFAULT_STATUS_QUERY
+#undef DEFAULT_STATUS_SCROLLED
 #undef DEFAULT_STATUS_UMODE
 #undef DEFAULT_STATUS_UPTIME
 #undef DEFAULT_STATUS_WINDOW
@@ -282,6 +288,7 @@
 #undef DEFAULT_STATUS_HOLD_LINES
 #undef DEFAULT_STATUS_NOTIFY
 #undef DEFAULT_STATUS_OVERWRITE
+#undef DEFAULT_STATUS_SCROLLED_LINES
 #undef DEFAULT_STATUS_SERVER
 #undef DEFAULT_STATUS_WINDOW
 
@@ -307,6 +314,8 @@
 #define DEFAULT_STATUS_MAIL "%y6(%y7M:%y5%M%y6)"
 #define DEFAULT_STATUS_MODE "%y6(%y5+%y4%+%y6)"
 #define DEFAULT_STATUS_QUERY "%y6(%y7Q:%y5%Q%y6)"
+#define DEFAULT_STATUS_SCROLLED " [..scr..]"
+#define DEFAULT_STATUS_SCROLLED_LINES " (%y2%s%y6)"
 #define DEFAULT_STATUS_UMODE "%y6(%y5+%y4%#%y6)"
 #define DEFAULT_STATUS_UPTIME "%y6|%y7Up:%y5 %dd %hh %mm%y6|"
 #define DEFAULT_STATUS_USER "?.??"
@@ -314,7 +323,7 @@
 #define DEFAULT_INPUT_PROMPT "%y3${N}%y6:%y3${C}%y6> "
 #define DEFAULT_STATUS_FORMAT "%y1 %y6[%y7OperVision%y6] %> %y5!S "
 #define DEFAULT_STATUS_FORMAT1 "%y1 %T %y4%*%@%y3%N %# %A%Q %>%M %1 "
-#define DEFAULT_STATUS_FORMAT2 "%y1 %C%+%y6|%y7lj:%y5%3%y6| %U %> %S%H%B%I%O%F %y5%W %y6|%y7load:%y5%!0%y6| %y6|%y3%!1%y6| "
+#define DEFAULT_STATUS_FORMAT2 "%y1 %C%+%y6|%y7lj:%y5%3%y6| %U%P%s %> %S%H%B%I%O%F %y5%W %y6|%y7load:%y5%!0%y6| %y6|%y3%!1%y6| "
 #define DEFAULT_STATUS_FORMAT3 "%y1 %y5QuickStat %> %y5lag/%y4%2 %y6[%y5DCC:%y4s%6%y5:%y4r%5%y5:%y4o%4%y6] "
 
 #elif defined(WANTANSI)
@@ -344,7 +353,7 @@
 #endif /* OPERVISION */
 
 #define DEFAULT_STATUS_FORMAT1 "%y1[%y2%R%y6] %y2%*%y6%y3%@%y6%y7%N%y6%#%C%+%A%Q%S%I%O %y3%W%y6 %F%y9%H%y6 %> [lj %y5%3%y6]%y0"
-#define DEFAULT_STATUS_FORMAT2 "%y1%1 [lag %y8%2%y6] %M [g %y8%6%y6] [s %y8%5%y6] [%y8%D%y6:%y8%E%y6:%y8%P%y6:%y8%L%y6:%y8%7%y6:%y8%8%y6]%B %> %T%y0"
+#define DEFAULT_STATUS_FORMAT2 "%y1%1 [lag %y8%2%y6] %M [g %y8%6%y6] [s %y8%5%y6]%P%s [%y8%D%y6:%y8%E%y6:%y8%X%y6:%y8%L%y6:%y8%7%y6:%y8%8%y6]%B %> %T%y0"
 #define DEFAULT_STATUS_FORMAT3 "%y1%U [topic %y8%9%y6] %> %y0"
 #define DEFAULT_STATUS_HOLD " [..more..]"
 #define DEFAULT_STATUS_HOLD_LINES " (%y2%B%y6)"
@@ -353,6 +362,8 @@
 #define DEFAULT_STATUS_NOTIFY " %ya[a:%F]%y1%y6"
 #define DEFAULT_STATUS_OVERWRITE " (%y2ow%y6)"
 #define DEFAULT_STATUS_QUERY " [%y4Q%y6/%y4%Q%y6]"
+#define DEFAULT_STATUS_SCROLLED " [..scr..]"
+#define DEFAULT_STATUS_SCROLLED_LINES " (%y2%s%y6)"
 #define DEFAULT_STATUS_SERVER " via %y7%S%y6"
 #define DEFAULT_STATUS_UMODE " (%y4+%#%y6)"
 #define DEFAULT_STATUS_UPTIME "[up %y8%dd %hh %mm%y6]"
