@@ -31,14 +31,12 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ctcp.c,v 1.48 2004/03/19 20:18:47 f Exp $
+ * $Id: ctcp.c,v 1.52 2006/10/31 12:31:27 f Exp $
  */
 
 #include "irc.h"
 
-#ifndef _Windows
 #include <pwd.h>
-#endif /* _Windows */
 
 #ifdef HAVE_UNAME
 # include <sys/utsname.h>
@@ -95,7 +93,7 @@ extern int  AutoReplyMatch _((char *));
 extern void Check4WordKick _((char *, NickList *, int, ChannelList *));
 /****************************************************************************/
 
-static	char	FAR CTCP_Reply_Buffer[BIG_BUFFER_SIZE + 1] = "";
+static	char	CTCP_Reply_Buffer[BIG_BUFFER_SIZE + 1] = "";
 
 static	void	do_new_notice_ctcp _((char *, char *, char **, char *));
 
@@ -211,7 +209,7 @@ char	*ctcp_type[] =
 	"NOTICE"
 };
 
-static	char	FAR ctcp_buffer[BIG_BUFFER_SIZE + 1];
+static	char	ctcp_buffer[BIG_BUFFER_SIZE + 1];
 
 /* This is set to one if we parsed an SED */
 int     sed = 0;
@@ -1253,12 +1251,8 @@ do_version(ctcp, from, to, cmd)
                 the_unix = un.sysname;
         }
         send_ctcp_reply(from, ctcp->name, "ircII %s %s %s :%s", irc_version, the_unix, the_version,
-#else
-#ifdef _Windows
-        send_ctcp_reply(from, ctcp->name, "ircII %s MS-Windows :%s", irc_version,
 #else
         send_ctcp_reply(from, ctcp->name, "ircII %s *IX :%s", irc_version,
-#endif /* _Windows */
 #endif /* HAVE_UNAME */
 		(tmp = get_string_var(CLIENTINFO_VAR)) ?  tmp : IRCII_COMMENT);
 #endif /* PARANOID */
@@ -1374,37 +1368,31 @@ do_finger(ctcp, from, to, cmd)
 	diff = time(0) - idle_time;
 	c = (diff == 1) ? ' ' : 's';
 	/* XXX - fix me */
-# ifdef _Windows
-	send_ctcp_reply(from, ctcp->name,
-		"IRCII For MS-Windows User Idle %d second%c",
-		(int)diff, c);
-# else
 	uid = getuid();
-#  ifdef DAEMON_UID
+# ifdef DAEMON_UID
 	if (uid != DAEMON_UID)
 	{
-#  endif /* DAEMON_UID */
+# endif /* DAEMON_UID */
 		if ((pwd = getpwuid(uid)) != NULL)
 		{
 			char	*tmp;
 
-#  ifndef GECOS_DELIMITER
-#   define GECOS_DELIMITER ','
-#  endif /* GECOS_DELIMITER */
+# ifndef GECOS_DELIMITER
+#  define GECOS_DELIMITER ','
+# endif /* GECOS_DELIMITER */
 			if ((tmp = index(pwd->pw_gecos, GECOS_DELIMITER)) != NULL)
 				*tmp = '\0';
 			send_ctcp_reply(from, ctcp->name,
 				"%s (%s@%s) Idle %d second%c", pwd->pw_gecos,
 				pwd->pw_name, hostname, (int)diff, c);
 		}
-#  ifdef DAEMON_UID
+# ifdef DAEMON_UID
 	}
 	else
 		send_ctcp_reply(from, ctcp->name,
 			"IRCII Telnet User (%s) Idle %d second%c",
 			realname, (int)diff, c);
-#  endif /* DAEMON_UID */
-# endif /* _Windows */
+# endif /* DAEMON_UID */
 #endif /* PARANOID */
 /**************************** PATCHED by Flier ******************************/
         }
@@ -1430,20 +1418,24 @@ do_atmosphere(ctcp, from, to, cmd)
         int     foundar = 0;
 		int		isshit;
 		int		isfriend;
-        char    thing;
+        char    *thing;
 #ifdef WANTANSI
         char    *color = CmdsColors[COLME].color3;
-        char    tmpbuf1[mybufsize / 2];
 #else
         char    *color = "";
 #endif
+        char    tmpbuf1[mybufsize / 2];
         void    (*func)();
         ChannelList *chan;
 	NickList *joiner;
         Window *oldwin;
 
-        if (get_int_var(HIGH_ASCII_VAR)) thing = '';
-        else thing = '*';
+#ifdef HAVE_ICONV_H
+        if (get_int_var(HIGH_ASCII_VAR)) thing = "\342\210\236";
+#else
+        if (get_int_var(HIGH_ASCII_VAR)) thing = "";
+#endif /* HAVE_ICONV_H */
+        else thing = "*";
         if (Stamp == 2) func = (void(*)()) say;
         else func = (void(*)()) put_it;
 /****************************************************************************/
@@ -1478,23 +1470,23 @@ do_atmosphere(ctcp, from, to, cmd)
 					put_it("* %s:%s %s", from, to, cmd);*/
 				if (is_current_channel(to, parsing_server_index, 0))
 #ifdef WANTANSI
-                                    func("%s%c%s %s%s%s %s%s%s",
+                                    func("%s%s%s %s%s%s %s%s%s",
                                           CmdsColors[COLME].color1, thing, Colors[COLOFF],
                                           color, from, Colors[COLOFF],
                                           CmdsColors[COLME].color5, cmd, Colors[COLOFF]);
 #else
-                                    func("%c %s%s%s %s", thing, color, from, color, cmd);
+                                    func("%s %s%s%s %s", thing, color, from, color, cmd);
 #endif
                                 else {
 #ifdef WANTANSI
-                                    snprintf(tmpbuf1,sizeof(tmpbuf1),"<%s%s%s> %s%c%s %s%s%s",
+                                    snprintf(tmpbuf1,sizeof(tmpbuf1),"<%s%s%s> %s%s%s %s%s%s",
                                            CmdsColors[COLME].color4, to, Colors[COLOFF],
                                            CmdsColors[COLME].color1, thing, Colors[COLOFF],
                                            color, from, Colors[COLOFF]);
                                     func("%s %s%s%s",tmpbuf1,
                                           CmdsColors[COLME].color5,cmd, Colors[COLOFF]);
 #else
-                                    func("<%s> %c %s%s%s %s", to, thing, color, from, color, cmd);
+                                    func("<%s> %s %s%s%s %s", to, thing, color, from, color, cmd);
 #endif
                                 }
 /****************************************************************************/
@@ -1522,26 +1514,26 @@ do_atmosphere(ctcp, from, to, cmd)
                             }
                         }
                         if (foundar &&
-                            (ARinWindow==3 ||
+                            (ARinWindow == 3 ||
                             (ARinWindow && chan->window != curr_scr_win))) {
 #ifdef WANTANSI
                             snprintf(tmpbuf1, sizeof(tmpbuf1),
-                                    "<%s%s%s> %s%c%s %s%s%s",
+                                    "<%s%s%s> %s%s%s %s%s%s",
                                     CmdsColors[COLME].color4, to, Colors[COLOFF],
                                     CmdsColors[COLME].color1, thing,
                                     Colors[COLOFF],
                                     color, from, Colors[COLOFF]);
 #else
-                            sprintf(tmpbuf1, "<%s> %c %s%s%s %s",
+                            sprintf(tmpbuf1, "<%s> %s %s%s%s %s",
                                     to, thing, color, from, color, cmd);
 #endif
-                            oldwin=to_window;
-                            if (ARinWindow==1) /* ON */
-                                to_window=curr_scr_win;
+                            oldwin = to_window;
+                            if (ARinWindow == 1) /* ON */
+                                to_window = curr_scr_win;
                             else { /* USER/BOTH */
-                                to_window=get_window_by_level(LOG_USER4);
-                                if (to_window==NULL)
-                                    to_window=curr_scr_win;
+                                to_window = get_window_by_level(LOG_USER4);
+                                if (to_window == NULL)
+                                    to_window = curr_scr_win;
                             }
 #ifdef WANTANSI
                             func("%s %s%s%s", tmpbuf1,
@@ -1549,6 +1541,7 @@ do_atmosphere(ctcp, from, to, cmd)
 #else
                             func("%s", tmpbuf1);
 #endif
+                            to_window = oldwin;
                         }
 /****************************************************************************/
 		}
@@ -1565,12 +1558,12 @@ do_atmosphere(ctcp, from, to, cmd)
 /**************************** PATCHED by Flier ******************************/
 				/*put_it("*> %s %s", from, cmd);*/
 #ifdef WANTANSI
-                                func("%s%c%s> %s%s%s %s%s%s",
+                                func("%s%s%s> %s%s%s %s%s%s",
                                       CmdsColors[COLME].color1, thing, Colors[COLOFF],
                                       color, from, Colors[COLOFF],
                                       CmdsColors[COLME].color5, cmd, Colors[COLOFF]);
 #else
-				func("%c> %s%s%s %s", thing, color, from, color, cmd);
+				func("%s> %s%s%s %s", thing, color, from, color, cmd);
 #endif
 /****************************************************************************/
 		}
