@@ -32,7 +32,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: dcc.c,v 1.44 2003/12/24 10:55:25 f Exp $
+ * $Id: dcc.c,v 1.47 2006/10/31 12:31:27 f Exp $
  */
 
 #include "irc.h"
@@ -215,7 +215,7 @@ struct	deadlist
 }	*deadlist = NULL;
 
 extern	int	in_ctcp_flag;
-extern	char	FAR MyHostName[];
+extern	char	MyHostName[];
 extern	struct	in_addr	MyHostAddr, forced_ip_addr;
 extern int dgets_errno;
 static	off_t	filesize = 0;
@@ -327,7 +327,7 @@ DCC_list *Client;
     double sent,oldsent;
 
     if (flags==DCC_FILEREAD || flags==DCC_FILEREGET)
-        sent=Client->bytes_read-Client->resendoffset;
+        sent=Client->bytes_read-Client->resendoffset+Client->bytes_read;
     else if (flags==DCC_FILEOFFER || flags==DCC_RESENDOFFER) {
         sent=Client->bytes_sent-Client->resendoffset;
         tmpstr="to";
@@ -1397,7 +1397,7 @@ dcc_filesend(args)
 	Client = dcc_searchlist(FileBuf, user, DCC_FILEOFFER, 1, filename);
 	if ((Client->file = open(Client->description, O_RDONLY | O_BINARY)) == -1)
 	{
-		say("Unable to open %s: %s\n", Client->description,
+		say("Unable to open %s: %s", Client->description,
 			errno ? strerror(errno) : "Unknown Host");
 		new_close(Client->read);
 		Client->read = Client->write = (-1);
@@ -1482,7 +1482,7 @@ dcc_resend(args)
 	Client = dcc_searchlist(FileBuf, user, DCC_RESENDOFFER, 1, filename);
 	if ((Client->file = open(Client->description, O_RDONLY | O_BINARY)) == -1)
 	{
-		say("Unable to open %s: %s\n", Client->description,
+		say("Unable to open %s: %s", Client->description,
 			errno ? strerror(errno) : "Unknown Host");
 		new_close(Client->read);
 		Client->read = Client->write = (-1);
@@ -1710,7 +1710,7 @@ dcc_regetfile(args)
 	struct stat buf;
 	struct transfer_struct transfer_orders;
 /**************************** PATCHED by Flier ******************************/
-        char *fullname1=(char *) 0;
+        char *fullname1 = NULL;
 /****************************************************************************/
 
 #ifdef  DAEMON_UID
@@ -1757,10 +1757,10 @@ dcc_regetfile(args)
 	if (0 == (fullname1 = expand_twiddle(Client->description)))
 		malloc_strcpy(&fullname1, Client->description);
         if (CdccDlDir) {
-            malloc_strcpy(&fullname,CdccDlDir);
-            malloc_strcat(&fullname,"/");
+            malloc_strcpy(&fullname, CdccDlDir);
+            malloc_strcat(&fullname, "/");
         }
-        malloc_strcat(&fullname,fullname1);
+        malloc_strcat(&fullname, fullname1);
         new_free(&fullname1);
 /****************************************************************************/
 
@@ -1917,6 +1917,7 @@ register_dcc_offer(user, type, description, address, port, size)
 	sscanf(port, "%u", &TempInt);
 	Client->remport = TempInt;
 /**************************** PATCHED by Flier ******************************/
+        Client->resendoffset = 0;
 	/*if (TempInt < 1024)
 	{
 		say("DCC %s (%s) request from %s rejected [port = %d]", type, description, user, TempInt);*/
@@ -2136,7 +2137,7 @@ process_incoming_chat(Client)
 		sra = sizeof(struct sockaddr_in);
 		Client->write = accept(Client->read, (struct sockaddr *)
 			&remaddr, &sra);
-#if defined(ESIX) || defined(_Windows)
+#if defined(ESIX)
 		mark_socket(Client->write);
 #endif
 		new_close(Client->read);
@@ -2259,7 +2260,7 @@ process_incoming_listen(Client)
 		Name = hp->h_name;
 	else
 		Name = inet_ntoa(remaddr.sin_addr);
-#if defined(ESIX) || defined(_Windows)
+#if defined(ESIX)
 	mark_socket(new_socket);
 #endif
 	snprintf(FdName, sizeof FdName, "%d", new_socket);
@@ -2446,7 +2447,7 @@ DCC_list *Client;
 		sra = sizeof(struct sockaddr_in);
 		Client->write = accept(Client->read,
 				(struct sockaddr *) &remaddr, &sra);
-#if defined(ESIX) || defined(_Windows)
+#if defined(ESIX)
 		mark_socket(Client->write);
 #endif
 /**************************** Patched by Flier ******************************/
@@ -2510,15 +2511,6 @@ DCC_list *Client;
 	{
  		if ((bytesread = recv(Client->read, (char *) &bytesrecvd, sizeof(u_32int), 0)) < sizeof(u_32int))
 		{
-#ifdef _Windows
-                    int	recv_error;
-
-                    recv_error = WSAGetLastError();
-                    if (bytesread == -1 &&
-                        recv_error == WSAEWOULDBLOCK ||
-                        recv_error == WSAEINTR)
-                             goto out;
-#endif /* _Windows */
 /**************************** Patched by Flier ******************************/
 	       		/*say("DCC SEND:%s connection to %s lost: %s", Client->description, Client->user, strerror(errno));*/
                         if ((Client->flags&DCC_TYPES)==DCC_RESENDOFFER)
@@ -2643,17 +2635,6 @@ process_incoming_file(Client)
 		snprintf(lame_ultrix, sizeof lame_ultrix, "%2.4g", (sent / (double)xtime));
 		say("DCC GET:%s from %s completed %s kb/sec",
 			Client->description, Client->user, lame_ultrix);*/
-#ifdef _Windows
-		{
-                    int	recv_error;
-
-                    recv_error = WSAGetLastError();
-                    if (bytesread == -1 &&
-                        recv_error == WSAEWOULDBLOCK ||
-                        recv_error == WSAEINTR)
-                        return;
-		}
-#endif /* _Windows */
  		save_message_from();
  		message_from(Client->user, LOG_DCC);
                 if ((Client->flags&DCC_TYPES)==DCC_FILEREGET)
