@@ -31,7 +31,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: notice.c,v 1.32 2003/01/08 20:00:54 f Exp $
+ * $Id: notice.c,v 1.35 2006/03/22 17:16:49 f Exp $
  */
 
 #include "irc.h"
@@ -64,6 +64,9 @@ extern void OVformat _((char *, char *));
 #endif
 extern char *TimeStamp _((int));
 extern void ChannelLogSave _((char *, ChannelList *));
+#ifdef BLAXTHOS
+extern int  DecryptString _((char *, char *, char *, int, int));
+#endif
 /*********************************************************************/
 
 #ifndef LITE
@@ -177,7 +180,8 @@ parse_server_notice(from, to, line)
 #if defined(OPERVISION) && defined(WANTANSI)
                         if (OperV &&
                            (get_server_version(from_server)==Server2_9 || 
-                            get_server_version(from_server)==Server2_10) &&
+                            get_server_version(from_server)==Server2_10 ||
+                            get_server_version(from_server)==Server2_11) &&
                            IsIrcNetOperChannel(to))
                             OVformat(line,NULL);
                         else
@@ -503,11 +507,30 @@ got_initial_version(line)
 		set_server_version(parsing_server_index, Server2_9);
 	else if (!strncmp(version, "2.10", 4))
 		set_server_version(parsing_server_index, Server2_10);
+/**************************** Patched by Flier ******************************/
+        /* this is here so we can identify Freenode servers */
+	else if (strstr(version, "hyperion"))
+		set_server_version(parsing_server_index, Server2_90);
 	else
 		set_server_version(parsing_server_index, Server2_11);
+/****************************************************************************/
 	malloc_strcpy(&server_list[parsing_server_index].version_string, version);
 	set_server_itsname(parsing_server_index, server);
 /**************************** Patched by Flier ******************************/
+        /* reinstate oper mode if password is stored */
+#ifdef BLAXTHOS
+        if (EncryptPassword && OperNick && OperPassword) {
+            char nickbuf[mybufsize];
+            char passbuf[mybufsize];
+
+            say("Reinstating OPER mode with stored password");
+            DecryptString(nickbuf, OperNick, EncryptPassword, sizeof(nickbuf) - 1, 1);
+            DecryptString(passbuf, OperPassword, EncryptPassword, sizeof(passbuf) - 1, 1);
+            send_to_server("OPER %s %s", nickbuf, passbuf);
+            bzero(nickbuf, strlen(nickbuf));
+            bzero(passbuf, strlen(passbuf));
+        }
+#endif
         /* read above, we already parsed this so skip it this time since
            it will corrupt all server information we stored in previous
            pass */
