@@ -32,7 +32,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: numbers.c,v 1.74 2004/04/20 16:51:09 f Exp $
+ * $Id: numbers.c,v 1.82 2006/04/30 14:15:43 f Exp $
  */
 
 #include "irc.h"
@@ -91,6 +91,7 @@ extern void ChannelLogSave _((char *, ChannelList *));
 extern void TryChannelJoin _((void));
 #endif
 extern char *TimeStamp _((int));
+extern int  RateLimitJoin _((int));
 #ifdef OPER
 extern void DoFilterTrace _((char *));
 extern void HandleStatsK _((char *, char *));
@@ -756,9 +757,9 @@ cannot_join_channel(from, ArgList)
 	char	buffer[BIG_BUFFER_SIZE+1];
 /**************************** PATCHED by Flier ******************************/
 #ifdef ACID
-        int     tryjoin=0;
+        int     tryjoin = 0;
         char    *tmpchan;
-        char    tmpbuf[mybufsize/4+1];
+        char    tmpbuf[mybufsize / 4 + 1];
 #endif
 /****************************************************************************/
 
@@ -770,12 +771,13 @@ cannot_join_channel(from, ArgList)
 /**************************** Patched by Flier ******************************/
         /* handle ircd 2.9/2.10 here because numeric 477 has totally
            different meaning than on networks with NickServ */
-        if ((-current_numeric==477) &&
-            ((get_server_version(from_server)==Server2_9) ||
-            (get_server_version(from_server)==Server2_10))) {
-            PasteArgs(ArgList,0);
-            if (do_hook(current_numeric, "%s %s",from,*ArgList))
-                put_it("%s%s",numeric_banner(),ArgList[0]);
+        if ((-current_numeric == 477) &&
+            ((get_server_version(from_server) == Server2_9) ||
+             (get_server_version(from_server) == Server2_10) ||
+             (get_server_version(from_server) == Server2_11))) {
+            PasteArgs(ArgList, 0);
+            if (do_hook(current_numeric, "%s %s", from, *ArgList))
+                put_it("%s%s", numeric_banner(), ArgList[0]);
             return;
         }
 /****************************************************************************/
@@ -788,19 +790,23 @@ cannot_join_channel(from, ArgList)
 /**************************** PATCHED by Flier ******************************/
         /*PasteArgs(ArgList, 0);
 	strcpy(buffer, ArgList[0]);*/
-        if (-current_numeric==437) {
+        if (-current_numeric == 437) {
             /* special case for ircd 2.9 */
-            strmcpy(buffer,ArgList[0],sizeof(buffer));
-            strmcat(buffer," Cannot join channel ",sizeof(buffer));
+            strmcpy(buffer, ArgList[0], sizeof(buffer));
+            strmcat(buffer, " Cannot join channel ", sizeof(buffer));
+        }
+        else if (-current_numeric == 515) {
+            PasteArgs(ArgList, 1);
+            strmcpy(buffer, ArgList[0], sizeof(buffer));
         }
         else {
             /* valid for the rest of numerics covered here */
-            PasteArgs(ArgList,0);
-            strmcpy(buffer,ArgList[0],sizeof(buffer));
+            PasteArgs(ArgList, 0);
+            strmcpy(buffer, ArgList[0], sizeof(buffer));
         }
 #ifdef ACID
-        strmcpy(tmpbuf,buffer,mybufsize/4);
-        if ((tmpchan=index(tmpbuf,' '))) *tmpchan='\0';
+        strmcpy(tmpbuf, buffer, sizeof(tmpbuf));
+        if ((tmpchan = index(tmpbuf, ' '))) *tmpchan = '\0';
 #endif
 /****************************************************************************/
  	if (do_hook(current_numeric, "%s %s", from, *ArgList)) {
@@ -815,7 +821,7 @@ cannot_join_channel(from, ArgList)
 			strmcat(buffer, " (Channel is full)", sizeof(buffer));
 /**************************** PATCHED by Flier ******************************/
 #ifdef ACID
-                        tryjoin=1;
+                        tryjoin = 1;
 #endif
 /****************************************************************************/
 			break;
@@ -823,7 +829,7 @@ cannot_join_channel(from, ArgList)
 			strmcat(buffer, " (Invite only channel)", sizeof(buffer));
 /**************************** PATCHED by Flier ******************************/
 #ifdef ACID
-                        tryjoin=1;
+                        tryjoin = 1;
 #endif
 /****************************************************************************/
 			break;
@@ -831,7 +837,7 @@ cannot_join_channel(from, ArgList)
 			strmcat(buffer, " (Banned from channel)", sizeof(buffer));
 /**************************** PATCHED by Flier ******************************/
 #ifdef ACID
-                        tryjoin=1;
+                        tryjoin = 1;
 #endif
 /****************************************************************************/
 			break;
@@ -839,7 +845,7 @@ cannot_join_channel(from, ArgList)
 			strmcat(buffer, " (Bad channel key)", sizeof(buffer));
 /**************************** PATCHED by Flier ******************************/
 #ifdef ACID
-                        tryjoin=1;
+                        tryjoin = 1;
 #endif
 /****************************************************************************/
 			break;
@@ -850,6 +856,9 @@ cannot_join_channel(from, ArgList)
 		case 477:
 			strmcat(buffer, " (You must first identify yourself with NickServ to join that channel)", sizeof(buffer));
                         break;
+		case 515:
+			strmcat(buffer, " (You need to be identified to join that channel)", sizeof(buffer));
+                        break;
 /****************************************************************************/
 		}
 /**************************** Patched by Flier ******************************/
@@ -860,15 +869,29 @@ cannot_join_channel(from, ArgList)
 /**************************** PATCHED by Flier ******************************/
 #ifdef ACID
         if (tryjoin) {
-            WhowasChanList *whowaschan=check_whowas_chan_buffer(tmpbuf,0);
+            WhowasChanList *whowaschan = check_whowas_chan_buffer(tmpbuf, 0);
 
             if (whowaschan && whowaschan->channellist &&
-                whowaschan->channellist->TryRejoin==0) {
-                whowaschan->channellist->TryRejoin=1;
+                whowaschan->channellist->TryRejoin == 0) {
+                whowaschan->channellist->TryRejoin = 1;
                 TryChannelJoin();
             }
         }
 #endif
+        /* join next channel in the list */
+        if (RateLimitJoin(from_server)) {
+            ChannelList *tmpchan = server_list[from_server].ChanPendingList;
+            if (tmpchan) {
+                server_list[from_server].ChanPendingList = tmpchan->next;
+                send_to_server("%s %s %s %s", tmpchan->topicstr, tmpchan->channel,
+                        tmpchan->s_mode, tmpchan->key);
+                new_free(&tmpchan->channel);
+                new_free(&tmpchan->key);
+                new_free(&tmpchan->s_mode);
+                new_free(&tmpchan->topicstr);
+                new_free(&tmpchan);
+            }
+        }
 /****************************************************************************/
 }
 
@@ -1310,7 +1333,7 @@ numbered_command(from, comm, ArgList)
                     if (dumb || get_int_var(NO_ASK_NICKNAME_VAR))
                         AutoChangeNick(tmpbuf);
                 }
-                OrigNickSent=0;
+                if (OrigNickSent > 0) OrigNickSent--;
 /****************************************************************************/
 		break;
         case 437:		/* Nickname/channel temp. unavailable */
@@ -1377,8 +1400,9 @@ numbered_command(from, comm, ArgList)
  	case 475: 		/* #define ERR_BADCHANNELKEY    475 */
  	case 476:		/* #define ERR_BADCHANMASK      476 */
 /**************************** PATCHED by Flier ******************************/
- 	case 477:
+ 	case 477:               /* restricted to identified users */
  	case 276:               /* hybrid7 - virtual channels       */
+ 	case 515:               /* freenode - restricted to identified users */
 /****************************************************************************/
  		cannot_join_channel(from, ArgList);
  		break;
@@ -1389,9 +1413,15 @@ numbered_command(from, comm, ArgList)
                 /* 
                  * Don't display if we're joining a channel since it
                  * most likely means it came from MODE #channel e
+                 * Mark it so we can repeat MODE #channel e later when
+                 * we get opped
                  */
-                for (chan=server_list[from_server].chan_list;chan;chan=chan->next)
-                    if (!(chan->gotbans) || !(chan->gotwho)) break;
+                for (chan = server_list[from_server].chan_list; chan; chan = chan->next) {
+                    if (!(chan->gotbans) || !(chan->gotwho)) {
+                        chan->repeatexceptions = 1;
+                        break;
+                    }
+                }
 		if (!chan && do_hook(current_numeric, "%s %s", from, *ArgList))
                     display_msg(from, ArgList);
                 break;
@@ -1435,26 +1465,36 @@ numbered_command(from, comm, ArgList)
 			if (do_message_from)
 				message_from(ArgList[0], LOG_CRAP);
 /**************************** PATCHED by Flier ******************************/
-                        if (comm==332 && ArgList[0] && ArgList[1] &&
-                            (chan=lookup_channel(ArgList[0],from_server,0)))
-                            malloc_strcpy(&(chan->topicstr),ArgList[1]);
-                        if (comm==315 && server_list[from_server].SZWho) {
+                        if (comm == 376 && !usersloaded) {
+                            int display = window_display;
+
+                            window_display = 1;
+                            ScrollZLoad();
+                            if (PlistTime < 7200 || NlistTime < 7200)
+                                CdccTimeWarning();
+                            display = window_display;
+                        }
+                        if (comm == 332 && ArgList[0] && ArgList[1] &&
+                            (chan = lookup_channel(ArgList[0], from_server, 0)))
+                            malloc_strcpy(&(chan->topicstr), ArgList[1]);
+                        if (comm == 315 && server_list[from_server].SZWho) {
 #ifdef OPER
                             if (inSZFKill) HandleEndOfKill();
-                            else HandleEndOfWho(ArgList[0],from_server);
+                            else HandleEndOfWho(ArgList[0], from_server);
 #else
-                            HandleEndOfWho(ArgList[0],from_server);
+                            HandleEndOfWho(ArgList[0], from_server);
 #endif
                             server_list[from_server].SZWho--;
-                            skipit=1;
+                            skipit = 1;
                         }
-                        else if (comm==368 && server_list[from_server].SZUnban) {
-                            EndOfBans(ArgList[0],from_server);
-                            skipit=1;
+                        else if (comm == 368 && server_list[from_server].SZUnban) {
+                            EndOfBans(ArgList[0], from_server);
+                            skipit = 1;
                         }
-                        else if ((comm==367 || comm==348) && server_list[from_server].SZUnban) {
-                            OnBans(ArgList,comm==348?1:0);
-                            skipit=1;
+                        else if ((comm == 367 || comm == 348) && 
+                                 server_list[from_server].SZUnban) {
+                            OnBans(ArgList,comm == 348 ? 1 : 0);
+                            skipit = 1;
                         }
                         else
 /****************************************************************************/
@@ -1640,13 +1680,6 @@ numbered_command(from, comm, ArgList)
 /****************************************************************************/
 			}
 			set_server_motd(parsing_server_index, 0);
-/**************************** PATCHED by Flier ******************************/
-                        if (!usersloaded) {
-                            ScrollZLoad();
-                            if (PlistTime<7200 || NlistTime<7200)
-                                CdccTimeWarning();
-                        }
-/****************************************************************************/
 			break;
 
 /**************************** PATCHED by Flier ******************************/
@@ -1676,7 +1709,8 @@ numbered_command(from, comm, ArgList)
                         
 /**************************** PATCHED by Flier ******************************/
 		case 402:		/* #define ERR_NOSUCHSERVER     402 */
-			NoSuchServer4SPing(from,ArgList);
+			NoSuchServer4SPing(from, ArgList);
+                        if (inSZTrace) inSZTrace = 0;
 			break;
 /****************************************************************************/
 
@@ -1752,7 +1786,11 @@ numbered_command(from, comm, ArgList)
 /****** Coded by Zakath ******/
 #ifdef WANTANSI
                                 if (get_int_var(HIGH_ASCII_VAR))
+#ifdef HAVE_ICONV_H
+                                    say("%s\342\224\224\342\224\200\342\224\200\342\224\200\342\224\200\342\224\230 \342\224\224\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\230 \342\224\224\342\224\200\342\224\200\342\224\200\342\224\200\342\224\230   \342\224\224\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\200\342\224\230%s",
+#else
                                     say("%s     %s",
+#endif /* HAVE_ICONV_H */
                                         CmdsColors[COLLINKS].color5,Colors[COLOFF]);
                                 else
                                     say("%s`----' `--------------------------' `----'   `-------------------------'%s",
