@@ -17,7 +17,7 @@
  * When user chooses to kill OperVision window with ^WK or WINDOW KILL
  * command, we disable OperVision since they probably wanted that.
  *
- * $Id: operv.c,v 1.69 2004/04/20 17:13:50 f Exp $
+ * $Id: operv.c,v 1.71 2004/10/19 18:55:50 f Exp $
  */
 
 #include "irc.h"
@@ -47,7 +47,8 @@ int  sizeofbuf;
 {
     /* we need to send aditional usermodes (+swfuckrn), for ircd 2.9/2.10 only send +w */
     if (get_server_version(from_server)==Server2_9 || 
-        get_server_version(from_server)==Server2_10)
+        get_server_version(from_server)==Server2_10 ||
+        get_server_version(from_server)==Server2_11)
         strmcpy(tmpbuf,"w",sizeofbuf);
     else strmcpy(tmpbuf,"swfuckrn",sizeofbuf);
 }
@@ -443,6 +444,8 @@ char *from;
             strcpy(word3,OVgetword(0,5,tmpline));  /* user */
 	    snprintf(word2,sizeof(word2),"(%s@%s)",word3,
                     OVgetword(0,7,tmpline));       /* host */
+            *word3='\0';
+            *word4='\0';
         }
         else {
             strcpy(word2,OVgetword(0,4,tmpline));  /* user@host */
@@ -1412,7 +1415,9 @@ char *from;
         strcpy(word3,OVgetword(0,6,tmpline));  /* o/O */
         tmp=word3;
         if (*tmp) tmp++;
-        if (get_server_version(from_server)==Server2_9 || get_server_version(from_server)==Server2_10) {
+        if (get_server_version(from_server)==Server2_9 ||
+            get_server_version(from_server)==Server2_10 ||
+            get_server_version(from_server)==Server2_11) {
             opertype=*tmp?(*tmp=='o'?2:1):0;
         }
         else {
