@@ -31,7 +31,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: server.c,v 1.59 2003/12/28 16:47:05 f Exp $
+ * $Id: server.c,v 1.63 2006/10/31 12:31:27 f Exp $
  */
 
 #include "irc.h"
@@ -67,6 +67,7 @@ int	connect_to_unix _((int, char *));
 extern void HandleClosedConn _((int, char *));
 extern int  CheckServer _((int));
 extern void ChannelLogReportAll _((char *, ChannelList *));
+extern char *OpenCreateFile _((char *, int));
 
 #ifdef HAVE_SSL
 int SSLconnect = 0;
@@ -180,9 +181,12 @@ close_server(server_index, message)
 				snprintf(buffer, sizeof buffer, "QUIT :%s\n", message);
 /**************************** Patched by Flier ******************************/
 #ifdef HAVE_SSL
-                                if (server_list[i].connected && server_list[i].enable_ssl) {
-                                    if (server_list[i].ssl_fd)
-                                        SSL_write(server_list[i].ssl_fd, buffer, strlen(buffer));
+                                if (server_list[i].connected &&
+                                    server_list[i].enable_ssl &&
+                                    server_list[i].session) {
+                                    if (gnutls_transport_get_ptr(server_list[i].session))
+                                        gnutls_record_send(server_list[i].session,
+                                                           buffer, strlen(buffer));
                                 }
                                 else
 #endif
@@ -199,20 +203,19 @@ close_server(server_index, message)
 			new_close(server_list[i].read);
 			server_list[i].read = -1;
 		}
-#ifndef _Windows
 		if (-1 != server_list[i].pid)
 		{
 			kill(server_list[i].pid, SIGKILL);
 			server_list[i].pid = (pid_t) -1;
 		}
-#endif /* _Windows */
 /**************************** Patched by Flier ******************************/
 #ifdef HAVE_SSL
-                if (server_list[i].enable_ssl && server_list[i].ssl_fd) {
-                    SSL_shutdown(server_list[i].ssl_fd);
-                    server_list[i].ssl_fd = NULL;
-                    server_list[i].ctx = NULL;
-                    server_list[i].meth = NULL;
+                if (server_list[i].enable_ssl && server_list[i].session &&
+                    gnutls_transport_get_ptr(server_list[i].session)) {
+                    gnutls_bye(server_list[i].session, GNUTLS_SHUT_RDWR);
+                    gnutls_deinit(server_list[i].session);
+                    gnutls_certificate_free_credentials(server_list[i].xcred);
+                    memset(&server_list[from_server].session, 0, sizeof(gnutls_session));
                 }
 #endif
 /****************************************************************************/
@@ -307,7 +310,7 @@ do_server(rd, wd)
 #ifdef HAVE_SSL
                         if (server_list[from_server].enable_ssl)
                             junk = SSL_dgets(bufptr, BIG_BUFFER_SIZE, des, (char *) 0,
-                                             server_list[from_server].ssl_fd);
+                                             &server_list[from_server].session);
                         else
 #endif /* HAVE_SSL */
 /****************************************************************************/
@@ -544,9 +547,10 @@ add_to_server_list(server, port, password, nick, overwrite)
 /**************************** PATCHED by Flier ******************************/
 #ifdef HAVE_SSL
                 server_list[from_server].enable_ssl = 0;
-                server_list[from_server].ssl_fd = NULL;
-                server_list[from_server].ctx = NULL;
-                server_list[from_server].meth = NULL;
+                memset(&server_list[from_server].session, 0,
+                       sizeof(gnutls_session));
+                memset(&server_list[from_server].xcred, 0,
+                       sizeof(gnutls_certificate_credentials));
                 /* this is true only when adding server(s) from a command line */
                 if (*server == '!') {
                     server++;
@@ -566,6 +570,7 @@ add_to_server_list(server, port, password, nick, overwrite)
                 server_list[from_server].nickcur = NULL;
                 server_list[from_server].nicklist = NULL;
                 server_list[from_server].ConnectTime = 0;
+                server_list[from_server].ChanPendingList = NULL;
 /****************************************************************************/
 		server_list[from_server].nickname = (char *) 0;
 		server_list[from_server].connected = 0;
@@ -662,6 +667,7 @@ remove_from_server_list(i)
 	Window	*tmp;
 /**************************** PATCHED by Flier ******************************/
         struct  nicks *tmpnick, *tmpnickfree;
+        ChannelList *tmpchan, *tmpchanfree;
 /****************************************************************************/
 
 	from_server = i;
@@ -701,10 +707,6 @@ remove_from_server_list(i)
 	if (server_list[i].ctcp_send_size)
 		new_free(&server_list[i].ctcp_send_size);
 /**************************** PATCHED by Flier ******************************/
-#ifdef HAVE_SSL
-        SSL_CTX_free(server_list[i].ctx);
-        new_free(&server_list[i].meth);
-#endif
         if (server_list[i].LastMessage) new_free(&(server_list[i].LastMessage));
         if (server_list[i].LastNotice) new_free(&(server_list[i].LastNotice));
         if (server_list[i].LastMessageSent) new_free(&(server_list[i].LastMessageSent));
@@ -722,14 +724,21 @@ remove_from_server_list(i)
             new_free(&(tmpnickfree->nick));
             new_free(&tmpnickfree);
         }
+        for (tmpchan = server_list[i].ChanPendingList; tmpchan;) {
+            tmpchanfree = tmpchan;
+            tmpchan = tmpchan->next;
+            new_free(&(tmpchanfree->channel));
+            new_free(&(tmpchanfree->key));
+            new_free(&(tmpchanfree->s_mode));
+            new_free(&(tmpchanfree->topicstr));
+            new_free(&tmpchanfree);
+        }
 /****************************************************************************/
 
 	/* update all the structs with server in them */
 	channel_server_delete(i);	/* fix `higher' servers */
 	clear_channel_list(i);
-#ifndef _Windows
 	exec_server_delete(i);
-#endif /* _Windows */
 	if (i < primary_server)
 		--primary_server;
 	if (i < from_server)
@@ -1032,9 +1041,6 @@ connect_to_server_process(server_name, port, nick)
 	int	port;
 	char	*nick;
 {
-#ifdef _Windows
-	return -1;
-#else
 	int	write_des[2],
 		read_des[2],
 		pid,
@@ -1129,7 +1135,6 @@ connect_to_server_process(server_name, port, nick)
 	server_list[from_server].pid = pid;
 	server_list[from_server].operator = 0;
 	return (0);
-#endif /* _Windows */
 }
 
 /*
@@ -1387,18 +1392,25 @@ login_to_server(server)
 #ifdef HAVE_SSL
         if (server_list[server].enable_ssl && (server_list[server].flags & SSL_CONNECT)) {
             int err;
+            int cert_type_priority[3] = { GNUTLS_CRT_X509,
+                                          GNUTLS_CRT_OPENPGP, 0 };
+            char *filepath;
 
+            filepath = OpenCreateFile("ca.pem", 1);
             say("SSL connect in progress ...");
-            SSLeay_add_ssl_algorithms();
-            server_list[server].meth = SSLv3_client_method();
-            SSL_load_error_strings();
-            server_list[server].ctx = SSL_CTX_new(server_list[server].meth);
-            CHK_NULL(server_list[server].ctx);
-            server_list[server].ssl_fd = SSL_new(server_list[server].ctx);
-            CHK_NULL(server_list[server].ssl_fd);
-            SSL_set_fd(server_list[server].ssl_fd, server_list[server].read);
-            err = SSL_connect(server_list[server].ssl_fd);
-            CHK_SSL(err);
+            gnutls_certificate_allocate_credentials(&server_list[server].xcred);
+            gnutls_certificate_set_x509_trust_file(server_list[server].xcred,
+                                                   filepath, GNUTLS_X509_FMT_PEM);
+            gnutls_init(&server_list[server].session, GNUTLS_CLIENT);
+            gnutls_set_default_priority(server_list[server].session);
+            gnutls_certificate_type_set_priority(server_list[server].session,
+                                                 cert_type_priority);
+            gnutls_credentials_set(server_list[server].session, GNUTLS_CRD_CERTIFICATE,
+                                   server_list[server].xcred);
+            gnutls_transport_set_ptr(server_list[server].session,
+                                     (gnutls_transport_ptr) server_list[server].read);
+            err = gnutls_handshake(server_list[server].session);
+
             server_list[server].flags &= ~SSL_CONNECT;
         }
 #endif
@@ -2386,14 +2398,16 @@ send_to_server(format, arg1, arg2, arg3, arg4, arg5,
 		{
 /**************************** Patched by Flier ******************************/
 #ifdef HAVE_SSL
-                        if (server_list[server].enable_ssl) {
+                        if (server_list[server].enable_ssl &&
+                            server_list[server].session) {
                             int err;
 
-                            if (!server_list[server].ssl_fd) {
-                                say("SSL write error - ssl socket = 0");
+                            if (!gnutls_transport_get_ptr(server_list[server].session)) {
+                                say("SSL write error - ssl socket");
                                 return;
                             }
-                            err = SSL_write(server_list[server].ssl_fd, lbuf, len);
+                            err = gnutls_record_send(server_list[server].session,
+                                                     lbuf, len);
                             }
                         else
 #endif
