@@ -31,7 +31,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: vars.c,v 1.25 2003/05/04 18:06:59 f Exp $
+ * $Id: vars.c,v 1.29 2006/10/31 12:31:27 f Exp $
  */
 
 #include "irc.h"
@@ -47,8 +47,8 @@
 #include "input.h"
 #include "ircaux.h"
 #include "whois.h"
-#include "translat.h"
 #include "ircterm.h"
+#include "translat.h"
 #include "output.h"
 #include "server.h"
 
@@ -97,6 +97,7 @@ extern  Screen	*screen_list, *current_screen;
 
 	int	loading_global = 0;
 
+static  void	check_variable_order _((void));
 static	int	find_variable _((char *, int *));
 static	void	exec_warning _((int));
 static	void	input_warning _((int));
@@ -112,22 +113,24 @@ static  void    SetDCCPorts _((char *));
 static	void	Cnotifystring _((char *));
 static  void    SetAwayFile _((char *));
 void    SetStampFormat _((char *));
+static  void    SetStatusLines _((int));
 
 extern  void    RedrawAll _((void));
+extern  void    UpdateFloodUsers _((void));
 
 extern  int     DCCLowPort;
 extern  int     DCCHighPort;
 extern	char	*CelerityNtfy;
 /****************************************************************************/
 
-#ifdef _Windows
-extern	char *get_ini_value(char *pchEntry);
-#endif /* _Windows */
-
 /*
  * irc_variable: all the irc variables used.  Note that the integer and
  * boolean defaults are set here, which the string default value are set in
- * the init_variables() procedure 
+ * the init_variables() procedur .
+ *
+ * this structure needs to be in alphabetical order, and the
+ * check_variable_order() procedure will assert that it is from
+ * init_variables()
  */
 static	IrcVariable irc_variable[] =
 {
@@ -170,12 +173,16 @@ static	IrcVariable irc_variable[] =
 /**************************** PATCHED by Flier ******************************/
 	{ "DISPLAY_ANSI",		BOOL_TYPE_VAR,	DEFAULT_DISPLAY_ANSI, NULL, RedrawAll, 0, 0 },
 /****************************************************************************/
+	{ "DISPLAY_ENCODING",		STR_TYPE_VAR,	0, NULL, set_display_encoding, 0, 0 },
 	{ "EIGHT_BIT_CHARACTERS",	BOOL_TYPE_VAR,	DEFAULT_EIGHT_BIT_CHARACTERS, NULL, eight_bit_characters, 0, 0 },
 	{ "ENCRYPT_PROGRAM",		STR_TYPE_VAR,	0, NULL, NULL, 0, VF_NODAEMON },
 	{ "EXEC_PROTECTION",		BOOL_TYPE_VAR,	DEFAULT_EXEC_PROTECTION, NULL, exec_warning, 0, VF_NODAEMON },
 	{ "FLOOD_AFTER",		INT_TYPE_VAR,	DEFAULT_FLOOD_AFTER, NULL, NULL, 0, 0 },
 	{ "FLOOD_RATE",			INT_TYPE_VAR,	DEFAULT_FLOOD_RATE, NULL, NULL, 0, 0 },
-	{ "FLOOD_USERS",		INT_TYPE_VAR,	DEFAULT_FLOOD_USERS, NULL, NULL, 0, 0 },
+/**************************** PATCHED by Flier ******************************/
+	/*{ "FLOOD_USERS",		INT_TYPE_VAR,	DEFAULT_FLOOD_USERS, NULL, NULL, 0, 0 },*/
+	{ "FLOOD_USERS",		INT_TYPE_VAR,	DEFAULT_FLOOD_USERS, NULL, UpdateFloodUsers, 0, 0 },
+/****************************************************************************/
 	{ "FLOOD_WARNING",		BOOL_TYPE_VAR,	DEFAULT_FLOOD_WARNING, NULL, NULL, 0, 0 },
 	{ "FULL_STATUS_LINE",		BOOL_TYPE_VAR,	DEFAULT_FULL_STATUS_LINE, NULL, update_all_status, 0, 0 },
 	{ "HELP_PAGER",			BOOL_TYPE_VAR,	DEFAULT_HELP_PAGER, NULL, NULL, 0, 0 },
@@ -201,11 +208,13 @@ static	IrcVariable irc_variable[] =
 /****************************************************************************/
 	{ "INDENT",			BOOL_TYPE_VAR,	DEFAULT_INDENT, NULL, NULL, 0, 0 },
 	{ "INPUT_ALIASES",		BOOL_TYPE_VAR,	DEFAULT_INPUT_ALIASES, NULL, NULL, 0, 0 },
+	{ "INPUT_ENCODING",		STR_TYPE_VAR,	0, NULL, set_input_encoding, 0, 0 },
 	{ "INPUT_PROMPT",		STR_TYPE_VAR,	0, NULL, set_input_prompt, 0, 0 },
 	{ "INPUT_PROTECTION",		BOOL_TYPE_VAR,	DEFAULT_INPUT_PROTECTION, NULL, input_warning, 0, 0 },
 	{ "INSERT_MODE",		BOOL_TYPE_VAR,	DEFAULT_INSERT_MODE, NULL, update_all_status, 0, 0 },
 	{ "INVERSE_VIDEO",		BOOL_TYPE_VAR,	DEFAULT_INVERSE_VIDEO, NULL, NULL, 0, 0 },
 	{ "IRCHOST",			STR_TYPE_VAR,	0, NULL, set_irchost, 0, 0 },
+	{ "IRC_ENCODING",		STR_TYPE_VAR,	0, NULL, set_irc_encoding, 0, 0 },
 	{ "LASTLOG",			INT_TYPE_VAR,	DEFAULT_LASTLOG, NULL, set_lastlog_size, 0, 0 },
 /**************************** PATCHED by Flier ******************************/
         { "LASTLOG_ANSI",		BOOL_TYPE_VAR,	1, NULL, NULL, 0, 0 },
@@ -230,8 +239,6 @@ static	IrcVariable irc_variable[] =
 #endif
 	{ "MINIMUM_SERVERS",		INT_TYPE_VAR,	DEFAULT_MINIMUM_SERVERS, NULL, NULL, 0, VF_NODAEMON },
 	{ "MINIMUM_USERS",		INT_TYPE_VAR,	DEFAULT_MINIMUM_USERS, NULL, NULL, 0, VF_NODAEMON },
-	{ "NO_ASK_NICKNAME",		BOOL_TYPE_VAR,	DEFAULT_NO_ASK_NICKNAME, NULL, NULL, 0, 0 },
-	{ "NO_CTCP_FLOOD",		BOOL_TYPE_VAR,	DEFAULT_NO_CTCP_FLOOD, NULL, NULL, 0, 0 },
 	{ "NOTIFY_HANDLER",		STR_TYPE_VAR, 	0, 0, set_notify_handler, 0, 0 },
 	{ "NOTIFY_LEVEL",		STR_TYPE_VAR,	0, NULL, set_notify_level, 0, 0 },
 	{ "NOTIFY_ON_TERMINATION",	BOOL_TYPE_VAR,	DEFAULT_NOTIFY_ON_TERMINATION, NULL, NULL, 0, VF_NODAEMON },
@@ -239,15 +246,17 @@ static	IrcVariable irc_variable[] =
 	{ "NOTIFY_STRING",		STR_TYPE_VAR,	0, NULL, Cnotifystring, 0, 0 },
 /****************************************************************************/
 	{ "NOVICE",			BOOL_TYPE_VAR,	DEFAULT_NOVICE, NULL, NULL, 0, 0 },
+	{ "NO_ASK_NICKNAME",		BOOL_TYPE_VAR,	DEFAULT_NO_ASK_NICKNAME, NULL, NULL, 0, 0 },
+	{ "NO_CTCP_FLOOD",		BOOL_TYPE_VAR,	DEFAULT_NO_CTCP_FLOOD, NULL, NULL, 0, 0 },
 	{ "OLD_ENCRYPT_PROGRAM",	BOOL_TYPE_VAR,	0, NULL, NULL, 0, VF_NODAEMON },
 	{ "REALNAME",			STR_TYPE_VAR,	0, 0, set_realname, 0, VF_NODAEMON },
 	{ "SAME_WINDOW_ONLY",		BOOL_TYPE_VAR,	DEFAULT_SAME_WINDOW_ONLY, NULL, NULL, 0, 0 },
 	{ "SCREEN_OPTIONS", 		STR_TYPE_VAR,	0, NULL, NULL, 0, VF_NODAEMON },
 	{ "SCROLL",			BOOL_TYPE_VAR,	DEFAULT_SCROLL, NULL, set_scroll, 0, 0 },
-	{ "SCROLL_LINES",		INT_TYPE_VAR,	DEFAULT_SCROLL_LINES, NULL, set_scroll_lines, 0, 0 },
 /**************************** PATCHED by Flier ******************************/
         { "SCROLLZ_STRING",             STR_TYPE_VAR,   0, NULL, SetScrollZstr, 0, 0 },
 /****************************************************************************/
+	{ "SCROLL_LINES",		INT_TYPE_VAR,	DEFAULT_SCROLL_LINES, NULL, set_scroll_lines, 0, 0 },
 	{ "SEND_IGNORE_MSG",		BOOL_TYPE_VAR,	DEFAULT_SEND_IGNORE_MSG, NULL, NULL, 0, 0 },
 	{ "SHELL",			STR_TYPE_VAR,	0, NULL, NULL, 0, VF_NODAEMON },
 	{ "SHELL_FLAGS",		STR_TYPE_VAR,	0, NULL, NULL, 0, VF_NODAEMON },
@@ -279,6 +288,7 @@ static	IrcVariable irc_variable[] =
 	{ "STATUS_HOLD_LINES",		STR_TYPE_VAR,	0, NULL, build_status, 0, 0 },
 	{ "STATUS_INSERT",		STR_TYPE_VAR,	0, NULL, build_status, 0, 0 },
 /**************************** PATCHED by Flier ******************************/
+        { "STATUS_LINES",		INT_TYPE_VAR,	DEFAULT_STATUS_LINES, NULL, SetStatusLines, 0, 0 },
         { "STATUS_LOADAVG",		STR_TYPE_VAR,	0, NULL, build_status, 0, 0 },
 /****************************************************************************/
 	{ "STATUS_MAIL",		STR_TYPE_VAR,	0, NULL, build_status, 0, VF_NODAEMON },
@@ -294,6 +304,8 @@ static	IrcVariable irc_variable[] =
         { "STATUS_REVERSE",		BOOL_TYPE_VAR,	1, NULL, build_status, 0, 0 },
 #endif
 /****************************************************************************/
+	{ "STATUS_SCROLLED",		STR_TYPE_VAR,	0, NULL, build_status, 0, 0 },
+	{ "STATUS_SCROLLED_LINES",	STR_TYPE_VAR,	0, NULL, build_status, 0, 0 },
 	{ "STATUS_SERVER",		STR_TYPE_VAR,	0, NULL, build_status, 0, 0 },
 	{ "STATUS_UMODE",		STR_TYPE_VAR,	0, NULL, build_status, 0, 0 },
 /**************************** PATCHED by Flier ******************************/
@@ -315,12 +327,10 @@ static	IrcVariable irc_variable[] =
 	{ "SUPPRESS_SERVER_MOTD",	BOOL_TYPE_VAR,	DEFAULT_SUPPRESS_SERVER_MOTD, NULL, NULL, 0, VF_NODAEMON },
 	{ "TAB",			BOOL_TYPE_VAR,	DEFAULT_TAB, NULL, NULL, 0, 0 },
 	{ "TAB_MAX",			INT_TYPE_VAR,	DEFAULT_TAB_MAX, NULL, NULL, 0, 0 },
-	{ "TRANSLATION",		STR_TYPE_VAR,	0, NULL, set_translation, 0, 0 },
 /**************************** PATCHED by Flier ******************************/
         { "TRUNCATE_PUBLIC_CHANNEL",	BOOL_TYPE_VAR, 	DEFAULT_TRUNCATE_PUBLIC_CHANNEL, NULL, NULL, 0, 0 },
 /****************************************************************************/
 	{ "UNDERLINE_VIDEO",		BOOL_TYPE_VAR,	DEFAULT_UNDERLINE_VIDEO, NULL, NULL, 0, 0 },
-	{ "USE_OLD_MSG",		BOOL_TYPE_VAR,	DEFAULT_USE_OLD_MSG, NULL, NULL, 0, 0 },
 	{ "USER_INFORMATION", 		STR_TYPE_VAR,	0, NULL, NULL, 0, 0 },
 	{ "USER_WALLOPS",		BOOL_TYPE_VAR,	DEFAULT_USER_WALLOPS, NULL, NULL, 0, 0 },
 	{ "VERBOSE_CTCP",		BOOL_TYPE_VAR,	DEFAULT_VERBOSE_CTCP, NULL, NULL, 0, 0 },
@@ -342,17 +352,21 @@ init_variables()
         int old_disp;
 /****************************************************************************/
 
+	check_variable_order();
+
 	set_string_var(CMDCHARS_VAR, DEFAULT_CMDCHARS);
 	set_string_var(LOGFILE_VAR, DEFAULT_LOGFILE);
 	set_string_var(SHELL_VAR, DEFAULT_SHELL);
 	set_string_var(SHELL_FLAGS_VAR, DEFAULT_SHELL_FLAGS);
 	set_string_var(DECRYPT_PROGRAM_VAR, UP(DEFAULT_DECRYPT_PROGRAM));
+	set_string_var(DISPLAY_ENCODING_VAR, DEFAULT_DISPLAY_ENCODING);
 	set_string_var(ENCRYPT_PROGRAM_VAR, DEFAULT_ENCRYPT_PROGRAM);
 	set_string_var(CONTINUED_LINE_VAR, DEFAULT_CONTINUED_LINE);
+	set_string_var(INPUT_ENCODING_VAR, DEFAULT_INPUT_ENCODING);
 	set_string_var(INPUT_PROMPT_VAR, DEFAULT_INPUT_PROMPT);
+	set_string_var(IRC_ENCODING_VAR, DEFAULT_IRC_ENCODING);
 	set_string_var(HIGHLIGHT_CHAR_VAR, DEFAULT_HIGHLIGHT_CHAR);
 	set_string_var(HISTORY_FILE_VAR, DEFAULT_HISTORY_FILE);
-	set_string_var(IRCHOST_VAR, empty_string);
 	set_string_var(LASTLOG_LEVEL_VAR, DEFAULT_LASTLOG_LEVEL);
 	set_string_var(NOTIFY_HANDLER_VAR, DEFAULT_NOTIFY_HANDLER);
 	set_string_var(NOTIFY_LEVEL_VAR, DEFAULT_NOTIFY_LEVEL);
@@ -382,6 +396,8 @@ init_variables()
 	set_string_var(STATUS_OPER_VAR, DEFAULT_STATUS_OPER);
 	set_string_var(STATUS_OVERWRITE_VAR, DEFAULT_STATUS_OVERWRITE);
 	set_string_var(STATUS_QUERY_VAR, DEFAULT_STATUS_QUERY);
+	set_string_var(STATUS_SCROLLED_VAR, DEFAULT_STATUS_SCROLLED);
+	set_string_var(STATUS_SCROLLED_LINES_VAR, DEFAULT_STATUS_SCROLLED_LINES);
 	set_string_var(STATUS_SERVER_VAR, DEFAULT_STATUS_SERVER);
 	set_string_var(STATUS_UMODE_VAR, DEFAULT_STATUS_UMODE);
 	set_string_var(STATUS_USER_VAR, DEFAULT_STATUS_USER);
@@ -397,15 +413,12 @@ init_variables()
 	set_beep_on_msg(DEFAULT_BEEP_ON_MSG);
 	set_string_var(STATUS_NOTIFY_VAR, DEFAULT_STATUS_NOTIFY);
 	set_string_var(CLIENTINFO_VAR, IRCII_COMMENT);
+#ifdef HAVE_ICONV_OPEN
+	set_irc_encoding(irc_variable[IRC_ENCODING_VAR].string);
+	set_input_encoding(irc_variable[INPUT_ENCODING_VAR].string);
+	set_display_encoding(irc_variable[DISPLAY_ENCODING_VAR].string);
+#endif /* HAVE_ICONV_OPEN */
 /**************************** PATCHED by Flier ******************************/
-        /* set below */
-/*#ifdef _Windows
-	set_string_var(TRANSLATION_VAR, "LATIN_1");
-	set_translation("LATIN_1");
-#else
-	set_string_var(TRANSLATION_VAR, "ASCII");
-	set_translation("ASCII");
-#endif*/ /* _Windows */
 	/*set_string_var(HELP_PATH_VAR, DEFAULT_HELP_PATH);*/
 /****************************************************************************/
 	set_lastlog_size(irc_variable[LASTLOG_VAR].integer);
@@ -429,20 +442,6 @@ init_variables()
         set_string_var(NOTIFY_STRING_VAR,CelerityNtfy);
         old_disp=window_display;
         window_display=0;
-#ifdef _Windows
-	set_string_var(TRANSLATION_VAR, "LATIN_1");
-	set_translation("LATIN_1");
-#else
-#if defined(WANTANSI)
-        if (get_int_var(HIGH_ASCII_VAR)) {
-            set_string_var(TRANSLATION_VAR,"LATIN_1");
-            set_translation("LATIN_1");
-        }
-#else
-	set_string_var(TRANSLATION_VAR, "ASCII");
-        set_translation("ASCII");
-#endif /* WANTANSI && HIGHASCII */
-#endif /* _Windows */
         window_display=old_disp;
         if (HelpPathVar) {
             set_string_var(HELP_PATH_VAR,HelpPathVar);
@@ -453,6 +452,24 @@ init_variables()
 /****************************************************************************/
 }
 
+/*
+ * check_variable_order: make sure irc_variable[] is properly ordered.
+ */
+static  void
+check_variable_order(void)
+{
+	IrcVariable *curr, *prev = NULL;
+	size_t  len;
+
+	for (curr = irc_variable; curr->name; prev = curr++)
+		if (prev && (len = strlen(prev->name)) && strncmp(prev->name, curr->name, len) > 0)
+		{
+			yell("irc_variables[] order is wrong at elements \"%s\" and \"%s\"!", prev->name, curr->name);
+			abort();
+		}
+
+}
+
 /*
  * find_variable: looks up variable name in the variable table and returns
  * the index into the variable array of the match.  If there is no match, cnt
@@ -1052,4 +1069,13 @@ char *tsformat;
                                    empty_string, &flag, NULL);
 #endif /* HAVE_STRFTIME */
 }
+
+static void SetStatusLines(value)
+int value;
+{
+    if (value > 3) value = 3;
+    if (value < 1) value = 1;
+    set_int_var(STATUS_LINES_VAR, value);
+    StatusLines = value - 1;
+}
 /****************************************************************************/
